summaryrefslogtreecommitdiff
path: root/src/theory/quantifiers/lazy_trie.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/theory/quantifiers/lazy_trie.cpp')
-rw-r--r--src/theory/quantifiers/lazy_trie.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/theory/quantifiers/lazy_trie.cpp b/src/theory/quantifiers/lazy_trie.cpp
index 3b1abb168..1b706d904 100644
--- a/src/theory/quantifiers/lazy_trie.cpp
+++ b/src/theory/quantifiers/lazy_trie.cpp
@@ -14,7 +14,7 @@
#include "theory/quantifiers/lazy_trie.h"
-namespace CVC4 {
+namespace CVC5 {
namespace theory {
namespace quantifiers {
@@ -154,6 +154,6 @@ void LazyTrieMulti::clear()
d_rep_to_class.clear();
}
-} /* CVC4::theory::quantifiers namespace */
-} /* CVC4::theory namespace */
-} /* CVC4 namespace */
+} // namespace quantifiers
+} // namespace theory
+} // namespace CVC5
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback